==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Storage invalid" : "Nieprawidłowy magazyn",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "Recent" : "Ostatnie",
    "Favorites" : "Ulubione",
    "File could not be found" : "Nie można znaleźć pliku",
    "Move or copy" : "Przenieś lub kopiuj",
    "Download" : "Pobierz",
    "Delete" : "Usuń",
    "Home" : "Start",
    "Close" : "Zamknij",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć katalogu \"{dir}\"",
    "This will stop your current uploads." : "Spowoduje to zatrzymanie wysyłania plików.",
    "Upload cancelled." : "Wysyłanie anulowane.",
    "Processing files …" : "Przetwarzam pliki...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Katalog docelowy \"{dir}\" już nie istnieje",
    "Not enough free space" : "Za mało wolnego miejsca",
    "An unknown error has occurred" : "Wystąpił nieznany błąd",
    "Uploading …" : "Wysyłanie…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Wysyłanie tego elementu nie jest wspierane",
    "Target folder does not exist any more" : "Katalog docelowy już nie istnieje",
    "Error when assembling chunks, status code {status}" : "Błąd podczas łączenia fragmentów, kod statusu {status}",
    "Actions" : "Akcje",
    "Rename" : "Zmień nazwę",
    "Copy" : "Kopiuj",
    "Choose target folder" : "Wybierz katalog docelowy",
    "Open" : "Otwórz",
    "Delete file" : "Usuń plik",
    "Delete folder" : "Usuń katalog",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj udostępnianie",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten katalog jest niedostępny, sprawdzić logi lub skontaktuj się z administratorem",
    "Could not move \"{file}\", target exists" : "Nie można przenieść \"{file}\" - plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "copy" : "kopia",
    "Could not copy \"{file}\", target exists" : "Nie można skopiować \"{file}\", plik już istnieje",
    "Could not copy \"{file}\"" : "Nie można skopiować \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopiowano {origin} wewnątrz {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopiowano {origin} oraz {nbfiles} innych plików wewnątrz {destination}",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest już używana w katalogu \"{dir}\". Wybierz inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć katalogu \"{dir}\", ponieważ już istnieje",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Brak wyników wyszukiwania w innych katalogach dla {tag}{filter}{endtag}",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowany",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "Select file range" : "Wybierz zakres plików",
    "{used} of {quota} used" : "Wykorzystane {used} z {quota}",
    "{used} used" : "Wykorzystane {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" jest niedozwolony w nazwie pliku.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" jest niedozwolony",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca dla {owner}, pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasujący '{filter}'","pasujące '{filter}'","pasujących '{filter}'","pasujących '{filter}'"],
    "View in folder" : "Zobacz w katalogu",
    "Copied!" : "Skopiowano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubiony",
    "Favorite" : "Ulubione",
    "You can only favorite a single file or folder at a time" : "Możesz dodać do ulubionych tylko pojedynczy plik lub katalog",
    "New folder" : "Nowy katalog",
    "Upload file" : "Wyślij plik",
    "Not favorited" : "Wyłączone z ulubionych",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas próby aktualizacji etykiet",
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote user\"" : "\"użytkownik zdalny\"",
    "You created {file}" : "Utworzy‭łeś {file}",
    "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
    "{user} created {file}" : "{user} utworzy‭ł {file}",
    "{user} created an encrypted file in {file}" : "{user} utworzył zaszyfrowany plik w {file}",
    "{file} was created in a public folder" : "{file} został utworzony w katalogu publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "You changed an encrypted file in {file}" : "Zmieniłeś zaszyfrowany plik w {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmienił zaszyfrowany plik w {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "You deleted an encrypted file in {file}" : "Usunąłeś zaszyfrowany plik w {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "{user} deleted an encrypted file in {file}" : "{user} usunął zaszyfrowany plik w {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z <strong>ulubionych</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Plik lub katalog został <strong>zmieniony</strong> lub <strong>zmieniono nazwę</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub katalog został <strong>utworzony</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub katalog został <strong>usunięty</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o tworzeniu i zmianach w <strong>ulubionych plikach</strong> <em>(Tylko transmisja strumieniowa)</em>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub katalog został <strong>przywrócony</strong>",
    "Unlimited" : "Brak limitu",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "Accept" : "Akceptuj",
    "Reject" : "Odrzuć",
    "Incoming ownership transfer from {user}" : "Przychodzące przeniesienie własności od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Czy chcesz zaakceptować {path}\n\nUwaga: Proces transferu po zaakceptowaniu może potrwać do 1 godziny.",
    "Ownership transfer failed" : "Przeniesienie własności nie powiodło się",
    "Your ownership transfer of {path} to {user} failed." : "Twoje przeniesienie własności {path} na {user} nie powiodło się.",
    "The ownership transfer of {path} from {user} failed." : "Przeniesienie własności {path} z {user} nie powiodło się.",
    "Ownership transfer done" : "Dokonano przeniesienia własności",
    "Your ownership transfer of {path} to {user} has completed." : "Twoje przeniesienie własności {path} na {user} zostało zakończone.",
    "The ownership transfer of {path} from {user} has completed." : "Przeniesienie własności {path} z {user} zostało zakończone.",
    "File Management" : "Zarządzanie plikami",
    "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
    "Choose file or folder to transfer" : "Wybierz plik lub katalog do przesłania",
    "Change" : "Zmień",
    "New owner" : "Nowy właściciel",
    "Search users" : "Wyszukaj użytkowników",
    "Choose a file or folder to transfer" : "Wybierz plik lub katalog do przesłania",
    "Transfer" : "Przeniesienia",
    "Transfer {path} to {userid}" : "Przenieś {path} do {userid}",
    "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
    "Ownership transfer request sent" : "Wysłano żądanie przeniesienia własności",
    "Tags" : "Etykiety",
    "Error while loading the file data" : "Błąd podczas ładowania danych pliku",
    "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
    "%s used" : "Wykorzystane: %s",
    "%s%% of %s used" : "Wykorzystane: %s%% z %s",
    "%1$s of %2$s used" : "Wykorzystane: %1$s z %2$s",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Użyj tego adresu, aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dostęp do swoich plików poprzez WebDAV</a>",
    "Toggle grid view" : "Przełącz widok siatki",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Wysyłany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites yet" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Deleted files" : "Usunięte pliki",
    "Shares" : "Udostępnione",
    "Shared with others" : "Udostępnione przez Ciebie",
    "Shared with you" : "Udostępnione dla Ciebie",
    "Shared by link" : "Udostępnione przez link",
    "Deleted shares" : "Usunięte współdzielenie",
    "Pending shares" : "Oczekujące udostępnienia",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "%s of %s used" : "Wykorzystano %s z %s",
    "%1$s%% of %2$s used" : "Wykorzystane: %1$s%% z %2$s"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-19.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Storage invalid" : "Nieprawidłowy magazyn",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "Recent" : "Ostatnie",
    "Favorites" : "Ulubione",
    "File could not be found" : "Nie można znaleźć pliku",
    "Move or copy" : "Przenieś lub kopiuj",
    "Download" : "Pobierz",
    "Delete" : "Usuń",
    "Home" : "Start",
    "Close" : "Zamknij",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć katalogu \"{dir}\"",
    "This will stop your current uploads." : "Spowoduje to zatrzymanie wysyłania plików.",
    "Upload cancelled." : "Wysyłanie anulowane.",
    "Processing files …" : "Przetwarzam pliki...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Katalog docelowy \"{dir}\" już nie istnieje",
    "Not enough free space" : "Za mało wolnego miejsca",
    "An unknown error has occurred" : "Wystąpił nieznany błąd",
    "Uploading …" : "Wysyłanie…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Wysyłanie tego elementu nie jest wspierane",
    "Target folder does not exist any more" : "Katalog docelowy już nie istnieje",
    "Error when assembling chunks, status code {status}" : "Błąd podczas łączenia fragmentów, kod statusu {status}",
    "Actions" : "Akcje",
    "Rename" : "Zmień nazwę",
    "Copy" : "Kopiuj",
    "Choose target folder" : "Wybierz katalog docelowy",
    "Open" : "Otwórz",
    "Delete file" : "Usuń plik",
    "Delete folder" : "Usuń katalog",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj udostępnianie",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten katalog jest niedostępny, sprawdzić logi lub skontaktuj się z administratorem",
    "Could not move \"{file}\", target exists" : "Nie można przenieść \"{file}\" - plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "copy" : "kopia",
    "Could not copy \"{file}\", target exists" : "Nie można skopiować \"{file}\", plik już istnieje",
    "Could not copy \"{file}\"" : "Nie można skopiować \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopiowano {origin} wewnątrz {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopiowano {origin} oraz {nbfiles} innych plików wewnątrz {destination}",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest już używana w katalogu \"{dir}\". Wybierz inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć katalogu \"{dir}\", ponieważ już istnieje",
    "Could not fetch file details \"{file}\"" : "Nie można pobrać szczegółów pliku \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Brak wyników wyszukiwania w innych katalogach dla {tag}{filter}{endtag}",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowany",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "Select file range" : "Wybierz zakres plików",
    "{used} of {quota} used" : "Wykorzystane {used} z {quota}",
    "{used} used" : "Wykorzystane {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" jest niedozwolony w nazwie pliku.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" jest niedozwolony",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca dla {owner}, pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasujący '{filter}'","pasujące '{filter}'","pasujących '{filter}'","pasujących '{filter}'"],
    "View in folder" : "Zobacz w katalogu",
    "Copied!" : "Skopiowano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubiony",
    "Favorite" : "Ulubione",
    "You can only favorite a single file or folder at a time" : "Możesz dodać do ulubionych tylko pojedynczy plik lub katalog",
    "New folder" : "Nowy katalog",
    "Upload file" : "Wyślij plik",
    "Not favorited" : "Wyłączone z ulubionych",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas próby aktualizacji etykiet",
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote user\"" : "\"użytkownik zdalny\"",
    "You created {file}" : "Utworzy‭łeś {file}",
    "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
    "{user} created {file}" : "{user} utworzy‭ł {file}",
    "{user} created an encrypted file in {file}" : "{user} utworzył zaszyfrowany plik w {file}",
    "{file} was created in a public folder" : "{file} został utworzony w katalogu publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "You changed an encrypted file in {file}" : "Zmieniłeś zaszyfrowany plik w {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmienił zaszyfrowany plik w {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "You deleted an encrypted file in {file}" : "Usunąłeś zaszyfrowany plik w {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "{user} deleted an encrypted file in {file}" : "{user} usunął zaszyfrowany plik w {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z <strong>ulubionych</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Plik lub katalog został <strong>zmieniony</strong> lub <strong>zmieniono nazwę</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub katalog został <strong>utworzony</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub katalog został <strong>usunięty</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o tworzeniu i zmianach w <strong>ulubionych plikach</strong> <em>(Tylko transmisja strumieniowa)</em>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub katalog został <strong>przywrócony</strong>",
    "Unlimited" : "Brak limitu",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "Accept" : "Akceptuj",
    "Reject" : "Odrzuć",
    "Incoming ownership transfer from {user}" : "Przychodzące przeniesienie własności od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Czy chcesz zaakceptować {path}\n\nUwaga: Proces transferu po zaakceptowaniu może potrwać do 1 godziny.",
    "Ownership transfer failed" : "Przeniesienie własności nie powiodło się",
    "Your ownership transfer of {path} to {user} failed." : "Twoje przeniesienie własności {path} na {user} nie powiodło się.",
    "The ownership transfer of {path} from {user} failed." : "Przeniesienie własności {path} z {user} nie powiodło się.",
    "Ownership transfer done" : "Dokonano przeniesienia własności",
    "Your ownership transfer of {path} to {user} has completed." : "Twoje przeniesienie własności {path} na {user} zostało zakończone.",
    "The ownership transfer of {path} from {user} has completed." : "Przeniesienie własności {path} z {user} zostało zakończone.",
    "File Management" : "Zarządzanie plikami",
    "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
    "Choose file or folder to transfer" : "Wybierz plik lub katalog do przesłania",
    "Change" : "Zmień",
    "New owner" : "Nowy właściciel",
    "Search users" : "Wyszukaj użytkowników",
    "Choose a file or folder to transfer" : "Wybierz plik lub katalog do przesłania",
    "Transfer" : "Przeniesienia",
    "Transfer {path} to {userid}" : "Przenieś {path} do {userid}",
    "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
    "Ownership transfer request sent" : "Wysłano żądanie przeniesienia własności",
    "Cannot transfer ownership of a file or folder you don't own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
    "Tags" : "Etykiety",
    "Error while loading the file data" : "Błąd podczas ładowania danych pliku",
    "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
    "%s used" : "Wykorzystane: %s",
    "%s%% of %s used" : "Wykorzystane: %s%% z %s",
    "%1$s of %2$s used" : "Wykorzystane: %1$s z %2$s",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Użyj tego adresu, aby uzyskać dostęp do plików poprzez WebDAV",
    "Toggle grid view" : "Przełącz widok siatki",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Wysyłany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites yet" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Deleted files" : "Usunięte pliki",
    "Shares" : "Udostępnione",
    "Shared with others" : "Udostępnione przez Ciebie",
    "Shared with you" : "Udostępnione dla Ciebie",
    "Shared by link" : "Udostępnione przez link",
    "Deleted shares" : "Usunięte współdzielenie",
    "Pending shares" : "Oczekujące udostępnienia",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "%s of %s used" : "Wykorzystano %s z %s",
    "%1$s%% of %2$s used" : "Wykorzystane: %1$s%% z %2$s",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Użyj tego adresu, aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dostęp do swoich plików poprzez WebDAV</a>",
    "Cannot transfter ownership of a file or folder you don't own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
